﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using HeuristicLab.Analysis;
using HeuristicLab.Core;
using HeuristicLab.Data;

namespace HeuristicLab.DataPreprocessing {
  public class LineChartLogic : ILineChartLogic {
 
    private ITransactionalPreprocessingData preprocessingData;

    public LineChartLogic(ITransactionalPreprocessingData preprocessingData) {
      this.preprocessingData = preprocessingData;
    }

    public DataTable CreateDataTable(String title) {
      DataTable dataTable = new DataTable(title);
      IEnumerable<string> variableNames = GetVariableNames();

      foreach (string variableName in variableNames) {
        DataRow row = CreateDataRow(variableName);
        dataTable.Rows.Add(row);
      }
      return dataTable;
    }

    public DataRow CreateDataRow(string variableName) {
      IList<double> values = preprocessingData.GetValues<double>(variableName);
      DataRow row = new DataRow(variableName, "", values);
      return row;
    }

    private IEnumerable<string> GetVariableNames() {
      List<string> doubleVariableNames = new List<string>();

      //only return variable names from type double
      foreach (string variableName in preprocessingData.VariableNames) {
        if (preprocessingData.IsType<double>(preprocessingData.GetColumnIndex(variableName)))
          doubleVariableNames.Add(variableName);
      }

      return doubleVariableNames;
    }

    public ICheckedItemList<StringValue> CreateVariableItemList() {
      ICheckedItemList<StringValue> itemList = new CheckedItemList<StringValue>();
      foreach (string name in GetVariableNames()) {
        itemList.Add(new StringValue(name), true);
      }
      return new ReadOnlyCheckedItemList<StringValue>(itemList);
    }

    public event DataPreprocessingChangedEventHandler Changed {
      add { preprocessingData.Changed += value; }
      remove { preprocessingData.Changed -= value; }
    }

    public string GetVariableNameByIndex(int index) {
      return preprocessingData.GetVariableName(index);
    }

  }
}
